@@ -3,7 +3,7 @@ package HTML::FormBuilder::Field;
 use strict;
 use warnings;
 use 5.008_005;
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use Carp;
 use Scalar::Util qw(weaken blessed);
@@ -66,7 +66,7 @@ sub build {
         if ($data->{'type'} and $data->{'type'} eq 'hidden') {
             $stacked_attr->{class} = $class;
         } else {
-            $stacked_attr->{class} = "$classes->{RowPadding} $classes->{row} clear$class";
+            $stacked_attr->{class} = "$classes->{row_padding} $classes->{row} clear$class";
         }
     }
 
