@@ -3,7 +3,7 @@ package HTML::FormBuilder::FieldSet;
 use strict;
 use warnings;
 use 5.008_005;
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use HTML::FormBuilder::Field;
 use Carp;
@@ -49,6 +49,15 @@ sub add_field {
     return $field;
 }
 
+sub add_fields {
+    my ($self, @field_args) = @_;
+
+    for my $field_arg (@field_args) {
+        $self->add_field($field_arg);
+    }
+    return scalar @field_args;
+}
+
 #####################################################################
 # Usage      : generate the form content for a fieldset
 # Purpose    : check and parse the parameters and generate the form
@@ -80,7 +89,7 @@ sub build {
     }
 
     if ($stacked == 0) {
-        $input_fields_html = $self->_build_element_and_attributes('div', {class => $self->{classes}{'NoStackFieldParent'}}, $input_fields_html);
+        $input_fields_html = $self->_build_element_and_attributes('div', {class => $self->{classes}{'no_stack_field_parent'}}, $input_fields_html);
     }
 
     $fieldset_html .= $input_fields_html;
@@ -193,7 +202,13 @@ The fields included by this fieldset.
 
     $fieldset->add_field({input => {type => 'text', value => 'name'}});
 
-append the field into fieldsets.
+append the field into fieldset and return that field
+
+=head2 add_fields
+
+    $fieldset->add_fields({input => {type => 'text', value => 'name'}},{input => {type => 'text', value => 'address'}});
+
+append fields into fieldset and return the number of fields added.
 
 =head1 AUTHOR
 
